@@ -23,7 +23,7 @@ def unpickle(filepath: str, encoding: str = "latin1") -> Any:
         encoding (str): Encoding used to unpickle.
 
     Returns:
-        unpickled: Unpickled object.
+        unpickled (Any): Unpickled object.
     """
     with open(filepath, "rb") as f:
         return pickle.load(f, encoding=encoding)  # nosec
